@@ -64,7 +64,12 @@ class BaseClient(ABC):
         """
         version = self._get_api_version()
         param_string = "/".join(path_params) if path_params else ""
-        return f"{self.BASE_URL}{version}/{self._get_endpoint()}/{param_string}"
+        return "{url}{api_version}/{endpoint}/{param_string}".format(
+            url=self.BASE_URL,
+            api_version=version,
+            endpoint=self._get_endpoint(),
+            param_string=param_string,
+        )
 
     def _execute_request(
         self, method: str, url: str, query_params: dict = None, json_data: dict = None
@@ -90,12 +95,14 @@ class BaseClient(ABC):
         request = method_switch.get(method.upper(), None)
 
         if not request:
-            raise FacturapiException(f"Method {method} not defined")
+            message = "Method {} not defined".format(method)
+            raise FacturapiException(message)
 
         try:
             response = request[0](url, **request[1])
         except Exception as error:
-            raise FacturapiException(f"Request error: {error}") from error
+            message = "Request error: {}".format(error)
+            raise FacturapiException(message) from error
 
         self.last_status = response.status_code
 
